@@ -207,4 +207,30 @@ class Imagem(models.Model):
     conta = models.ForeignKey('Conta', db_column="conta_id")
 
     class Meta:
-        db_table = u"plataforma\".\"tb_imagem"
\ No newline at end of file
+        db_table = u"plataforma\".\"tb_imagem"
+
+
+class Index(models.Model):
+    id = models.AutoField(db_column="index_id", primary_key=True)
+    status = models.IntegerField(db_column="index_status", default=1, null=False)
+    status_alt = models.IntegerField(db_column="index_status_alt", default=1, null=False)
+    produto = models.ForeignKey("catalogo.Produto", related_name='produto_index', null=True)
+    categoria = models.ForeignKey("catalogo.Categoria", related_name='categoria_indexar', null=True)
+    data_atualizacao = models.DateTimeField(db_column="index_data_atualizacao", auto_now=True)
+    conta = models.ForeignKey('plataforma.Conta', related_name='conta_indexar')
+    mensagem_erro = models.TextField(db_column="index_mensagem_erro", null=True)
+
+    class Meta:
+        db_table = u"plataforma\".\"tb_index"
+        verbose_name = u'Indexar'
+        verbose_name_plural = u"Indexar"
+
+    def indexado(self):
+        self.status = 0
+        self.save()
+
+    def erro(self, msg):
+        self.status = 1
+        self.status_alt = 1
+        self.mensagem_erro = msg
+        self.save()
